Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1674)

Unified Diff: runtime/include/dart_api.h

Issue 2350633003: Add Dart_GetStickyError (Closed)
Patch Set: turnidge review Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | runtime/vm/dart_api_impl.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/include/dart_api.h
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h
index 3d02adc5312e2c30696626048e5a050bc6467afe..c9c0d1a926e4168cc5ed4f11adbb7496f80109e2 100755
--- a/runtime/include/dart_api.h
+++ b/runtime/include/dart_api.h
@@ -1178,9 +1178,10 @@ DART_EXPORT void Dart_SetPausedOnExit(bool paused);
/**
* Called when the embedder has caught a top level unhandled exception error
- * in the current isolate. Also marks the isolate as paused at exit.
+ * in the current isolate.
*
* NOTE: It is illegal to call this twice on the same isolate.
*
* \param error The unhandled exception error.
*/
@@ -1194,6 +1195,14 @@ DART_EXPORT bool Dart_HasStickyError();
/**
+ * Gets the sticky error for the current isolate.
+ *
+ * \return A handle to the sticky error object or null.
+ */
+DART_EXPORT Dart_Handle Dart_GetStickyError();
siva 2016/09/22 19:43:54 Do we need both Dart_HasStickyError and Dart_GetSt
+
+
+/**
* Handles the next pending message for the current isolate.
*
* May generate an unhandled exception error.
@@ -1178,9 +1178,10 @@ DART_EXPORT void Dart_SetPausedOnExit(bool paused);
*
- * NOTE: It is illegal to call this twice on the same isolate.
+ * NOTE: It is illegal to call this twice on the same isolate without first
+ * clearing the sticky error to null.
*
* \param error The unhandled exception error.
« no previous file with comments | « no previous file | runtime/vm/dart_api_impl.cc » ('j') | runtime/vm/dart_api_impl.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698